%global with_zts    0%{?__ztsphp:1}
%global with_tests  0%{?_with_tests:1}
%global modname   amqp
%global pecl_name   amqp
%global ini_name    40-%{pecl_name}.ini
%define _disable_ld_no_undefined 1
%define php_extdir  %{_libdir}/php/extensions
%define php_inidir %{_sysconfdir}/php.d/
%define pecl_xmldir %{_sharedstatedir}/php/peclxml
%define prever dev

Summary:	Communicate with any AMQP compliant server
Name:		php-amqp
Version:	1.10.3
Release:	%mkrel -c git20201230 1
License:	PHP
Group:		Development/Other
URL:		http://pecl.php.net/package/amqp
Source0:	php-amqp-master.zip
##Source0:	http://pecl.php.net/get/%%{pecl_name}-%%{version}%%{?prever}.tgz
BuildRequires:	mercurial
BuildRequires:	php-pear
BuildRequires:	pkgconfig(librabbitmq) >= 0.5.2
%if %{with_tests}
BuildRequires:	rabbitmq-server
%endif

BuildRequires:	php-devel >= 3:8.0.0
Requires:       php >= 3:8.0.0
Requires:       php-common = 3:8.0

Provides:	php-pecl-%{pecl_name}          = %{version}
Provides:	php-pecl(%{pecl_name})         = %{version}



%description
This extension can communicate with any AMQP spec 0-9-1 compatible server,
such as RabbitMQ, OpenAMQP and Qpid, giving you the ability to create and
delete exchanges and queues, as well as publish to any exchange and consume
from any queue.


%prep
%autosetup -S hg -n php-amqp-master
##-n %{modname}-%{version}
# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

sed -e 's/CFLAGS="-I/CFLAGS="$CFLAGS -I/' -i config.m4

# Upstream often forget to change this
extver=$(sed -n '/#define PHP_AMQP_VERSION/{s/.* "//;s/".*$//;p}' php_amqp.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
cd ..

cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension = %{pecl_name}.so

; Whether calls to AMQPQueue::get() and AMQPQueue::consume()
; should require that the client explicitly acknowledge messages.
; Setting this value to 1 will pass in the AMQP_AUTOACK flag to
; the above method calls if the flags field is omitted.
;amqp.auto_ack = 0

; The host to which to connect.
;amqp.host = localhost

; The login to use while connecting to the broker.
;amqp.login = guest

; The password to use while connecting to the broker.
;amqp.password = guest

; The port on which to connect.
;amqp.port = 5672

; The number of messages to prefect from the server during a
; call to AMQPQueue::get() or AMQPQueue::consume() during which
; the AMQP_AUTOACK flag is not set.
;amqp.prefetch_count = 3

; The virtual host on the broker to which to connect.
;amqp.vhost = /

; Timeout
;amqp.timeout =
;amqp.read_timeout = 0
;amqp.write_timeout = 0
;amqp.connect_timeout = 0

;amqp.channel_max = 256
;amqp.frame_max = 131072
;amqp.heartbeat = 0

;amqp.cacert = ''
;amqp.cert = ''
;amqp.key = ''
;amqp.verify = ''
;amqp.sasl_method = 0
EOF

%if %{with_zts}
cp -pr NTS ZTS
%endif


%build
%{_bindir}/phpize
#rm -f aclocal.m4
#autoreconf -fi
%configure --with-php-config=%{_bindir}/php-config --with-libdir=%{_lib}
%make_build

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure --with-php-config=%{_bindir}/zts-php-config
%make_build
%endif


%install
%make_build install INSTALL_ROOT=%{buildroot}

# Drop in the bit of configuration
install -Dpm 644 ../%{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -Dpm 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_build -C ZTS install INSTALL_ROOT=%{buildroot}
install -Dpm 644 ../%{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
/usr/bin/php --no-php-ini \
    --define extension=modules/%{pecl_name}.so \
    -m | grep %{pecl_name}

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=ZTS/modules/%{pecl_name}.so \
    -m | grep %{pecl_name}
%endif

%if %{with_tests}
mkdir log run base
: Launch the RabbitMQ service
export RABBITMQ_PID_FILE=$PWD/run/pid
export RABBITMQ_LOG_BASE=$PWD/log
export RABBITMQ_MNESIA_BASE=$PWD/base
/usr/lib/rabbitmq/bin/rabbitmq-server &>log/output &
/usr/lib/rabbitmq/bin/rabbitmqctl wait $RABBITMQ_PID_FILE

ret=0
pushd NTS
: Run the upstream test Suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff || ret=1
popd

%if %{with_zts}
pushd ZTS
: Run the upstream test Suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php --show-diff || ret=1
popd
%endif

: Cleanup
if [ -s $RABBITMQ_PID_FILE ]; then
   kill $(cat $RABBITMQ_PID_FILE)
fi
rm -rf log run base

exit $ret
%endif


%files
%license LICENSE
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Dec 30 2020 mokraemer <mokraemer> 1.10.3-0.git20201230.1.mga8
+ Revision: 1665439
- pre release for php8

* Thu Jun 18 2020 mokraemer <mokraemer> 1.10.2-2.mga8
+ Revision: 1596247
- fix dep to current version

* Mon Apr 06 2020 mokraemer <mokraemer> 1.10.2-1.mga8
+ Revision: 1565134
- new version 1.10.2

* Tue Feb 18 2020 umeabot <umeabot> 1.9.4-3.mga8
+ Revision: 1539062
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Nov 29 2019 mokraemer <mokraemer> 1.9.4-2.mga8
+ Revision: 1463511
+ rebuild (emptylog)

* Thu Jan 31 2019 daviddavid <daviddavid> 1.9.4-1.mga7
+ Revision: 1362144
- new version: 1.9.4 (fixes build with PHP 7.3)

* Sun Sep 23 2018 umeabot <umeabot> 1.9.3-4.mga7
+ Revision: 1300207
- Mageia 7 Mass Rebuild

* Wed Apr 11 2018 pterjan <pterjan> 1.9.3-3.mga7
+ Revision: 1217351
- Rebuild for php 7.2, it was built with old php on arm

* Sun Dec 03 2017 mokraemer <mokraemer> 1.9.3-2.mga7
+ Revision: 1180957
+ rebuild (emptylog)

* Tue Nov 14 2017 zezinho <zezinho> 1.9.3-1.mga7
+ Revision: 1177348
- new version

* Mon Jul 11 2016 luigiwalser <luigiwalser> 1.7.0-3.mga6
+ Revision: 1041162
- fix php-amqp package name

* Fri Jul 08 2016 neoclust <neoclust> 1.7.0-2.mga6
+ Revision: 1039846
- Remove requires
- imported package php-pecl-amqp

